<?php

namespace Drupal\Tests\geofield_directions\Unit;

use Drupal\Component\Utility\Html;
use Drupal\geofield_directions\Plugin\Field\FieldFormatter\GeofieldDirectionsFormatter;
use Drupal\Tests\UnitTestCase;

/**
 * Test case for 'geofield_directions' formatter.
 *
 * @group geofield_directions
 */
class GeofieldDirectionsFormatterTest extends UnitTestCase {

  /**
   * Test HTML attributes parsing.
   *
   * @covers       GeofieldDirectionsFormatter::parseHtmlAttributes
   * @dataProvider attributesProvider
   */
  public function testParseHtmlAttributes($attributes, $expected_value) {
    $this->assertEquals($expected_value, GeofieldDirectionsFormatter::parseHtmlAttributes($attributes));
  }

  /**
   * Data provider for testParseHtmlAttributes().
   */
  public function attributesProvider(): array {
    $data = [];
    for ($i = 0; $i < 9; $i++) {
      $classes = join(' ', array_map(function ($item) {
        return Html::getClass($item);
      }, explode(' ', $this->getRandomGenerator()->sentences(2, FALSE))));
      $attribute = 'data-' . $this->randomMachineName(8);
      $value = $this->getRandomGenerator()->word(6);
      $data[] = [
        join(';', ["class=$classes", "$attribute=$value", 'href=/some/url/that/works', 'target=_self']),
        [
          'class' => explode(' ', $classes),
          $attribute => $value,
        ],
      ];
    }

    return $data;
  }

}
